<?php
/***************************************************************************
 *                         find_functionsNews.php
 *                         ----------------------
 *   Description:
 *   	This module contains functions for retrieving news feeds from
 *   	designated sites, formatting the parsed news items, and then
 *   	inserting them into the phpBB database.
 *
 *   Last Updated	:	Wednesday, March 14, 2007
 *   By             :	John MacAuley - The Comic Haven
 *   E-mail         :	hacksaw@thecomichaven.com
 *
 *   Version		: 	1.2.0
 *
 *   Changes:
 *   1.2.0  - Added a large number of new configuration options to permit
 *            more flexibility in post content.
 *          - Added ability to generate a single post for all items in a
 *            single RSS feed.
 *          - Fixed multiple post bug.
 *   1.1	- Added parsing to remove unwanted HMTL tags or conversion
 *   		  to associated bbcode version.
 *   		- Added new formatting for bbcode layout of news items.
 *   		- Added option for new html table formatting for news items.
 *   		- Added support for output of iTunes podcast feeds.
 *   		- Added support for additional tags found in rss, rdf, atom,
 *   		  iTunes news feeds.
 *
 ***************************************************************************/

// phpBB globals used for includes.
global $phpbb_root_path, $phpEx;

// Make sure someone isn't trying to invoke this directly.
if (!defined('IN_PHPBB'))
{
	die('Hacking attempt');
}

// Include all the files we will need.  There are some include_once
// statements later in the code.
include($phpbb_root_path . 'includes/bbcode.'. $phpEx);
include($phpbb_root_path . 'includes/functions_post.'. $phpEx);
include($phpbb_root_path . 'includes/functions_search.'. $phpEx);
include($phpbb_root_path . 'includes/find_config.'. $phpEx);
include($phpbb_root_path . 'includes/find_rssParser.'. $phpEx);
include($phpbb_root_path . 'includes/find_functionsFormat.'. $phpEx);
include($phpbb_root_path . 'includes/find_functionsInsertPost.'. $phpEx);


/***************************************************************************
 *                         retrieve_rss_content
 *                         --------------------
 *   Description:
 *   	This function quarterbacks the entire process by retrieving the list
 *   	of news feeds from the database, retrieving and parsing each feed,
 *   	and dispatching to appropriate post handler based on if multiple
 *   	posts or a single post.
 *
 *   Last Updated	:	Wednesday, March 14, 2007
 *   By				:	John MacAuley - The Comic Haven
 *   E-mail			:	hacksaw@thecomichaven.com
 *
 *   Version		: 	1.2.0
 *
 *   Changes:
 *   1.2.0	- Restructured code to support single post feature.
 *   1.1	- Added code to handle differences in regular and podcast news
 *   		  feeds.
 *			- Added handling for additional HTML formatting option.
 *			- Added removal of HTML tags from the news item topic.
 *
 *   Parameters:
 *       $newsfeed_ids	- a comma seperated list of newsfeed ids
 *       $do_sync		- auto resync the post count of the forum
 *
 *   Returns:
 *       String		- A message detailing what succeeded and what
 *       		  	  failed.
 *
 ***************************************************************************/
function retrieve_rss_content($newsfeed_ids = '', $do_sync = false)
{
    global $db;                     // phpBB globals.
    global $USE_CURL, $FIND_DEBUG;  // FIND globals.
 
    // retrieve the newsfeed info for the requested newsfeeds
    if (!empty($newsfeed_ids))
    {
      $newsfeed_sql = ' WHERE feed_id IN (' . $newsfeed_ids . ')';
    }

    $sql = 'SELECT * FROM ' . NEWSFEEDS_TABLE . $newsfeed_sql;

    if (!($feed_result = $db->sql_query($sql)))
    {
		if ($FIND_DEBUG)
		{
	    	print("retrieve_rss_content: could not obtain Newsfeed information " .
                " from database.<br />\n");
	    	return("<br><b>Failed to complete due to errors</b><br />\n");
		}

		message_die(GENERAL_ERROR, 'Could not obtain Newsfeed information.', '',
                        __LINE__, __FILE__, $sql);
    }

    $success_message = '';
    $error_message = '';
    
    // Instantiate a parser with the given url, retrieve the results and
    // format them for input into the forums.
    while ($feed_row = $db->sql_fetchrow($feed_result))
    {
		if ($FIND_DEBUG)
		{
	    	print("retrieve_rss_content: processing entry...<br />\n<pre>\n");
	    	print_r($feed_row);
	    	print("</pre><br />\n");
		}

        $news_url = $feed_row['news_url'];
        $encoding = $feed_row['news_encoding'];

		// Retrieve and parse the news rss feed.
		$rss_parser = new rssParser($USE_CURL, $FIND_DEBUG);

    	if ($rss_parser->parse($news_url, $encoding))
		{
	  		// Determine if this feed is a single or multiple posts.
	  		if ($feed_row['single_post'])
          	{
	      		$processed = createSinglePost($feed_row, $rss_parser); 
	  		}
	  		else
	  		{
              	$processed = createMultiplePosts($feed_row, $rss_parser); 
	  		}

	  		$success_message .= $news_url . ' processed ' . $processed .
		  		" new item(s).<br />\n";
    	}
        else
        {
	    	$error_message .= $news_url . "<br />\n" .
				$rss_parser->error_msg . "<br />\n<br />\n";
            if ($FIND_DEBUG)
	    	{
	        	print("retrieve_rss_content: " . $error_message);
	    	}
		}

        $rss_parser->destroy();
		unset($rss_parser);
    }

    $db->sql_freeresult($feed_result);
		
    $success_message = "<br />\nCompleted: <b>successfully</b>:<br />\n" .
        (($success_message == '') ? "None" : $success_message);
    $error_message = "<br />\nCompleted: <b>with problems</b>:<br />\n" .
        (($error_message == '') ? "None" : $error_message);
    
    return($success_message . "<br />\n<br />\n" . $error_message);

} /* retrieve_rss_content() */


/***************************************************************************
 *                         createMultiplePosts
 *                         -------------------
 *   Description:
 *   	This function is the post handler for those RSS feeds that have a
 *      post per item.
 *
 *   Last Updated	:	Wednesday, March 14, 2007
 *   By				:	John MacAuley - The Comic Haven
 *   E-mail			:	hacksaw@thecomichaven.com
 *
 *   Version		: 	1.2.0
 *
 *   Changes:
 *   1.2.0	- Restructured code to support single post feature.
 *          - Added new configuration options.
 *          - Fixed multiple post bug due to htmp entity conversion in the
 *            MySQL database insert.
 *   1.1	- Added code to handle differences in regular and podcast news
 *   		  feeds.
 *			- Added handling for additional HTML formatting option.
 *			- Added removal of HTML tags from the news item topic.
 *
 *   Parameters:
 *       $feed_row      - RSS feed data from FIND configuration database.
 *       $rss_parser    - Parsed RSS instance document.
 *
 *   Returns:
 *       String		- The number of RSS items processed (represents the
 *                    number of forum posts generated by this funtion).
 *
 ***************************************************************************/
function createMultiplePosts($feed_row, $rss_parser)
{
    global $phpbb_root_path, $board_config, $phpEx, $lang;    // phpBB globals.
    global $FIND_DEBUG, $FIND_DATE_FORMAT, $FIND_TIME_FORMAT; // FIND globals.
 
    // Pull out the post configuration information.
    $forum_id = $feed_row['forum_id'];
    $limit = $feed_row['news_limit'];
    $user_id = $feed_row['user_id'];

    // These are the post formatting options.
    $prefixTopic = $feed_row['topic_prefix'];
    $stripTopic = $feed_row['strip_topic'];
    $includeIcon = $feed_row['include_icon'];
    $isPodcast = $feed_row['is_podcast'];
    $includeTitle = $feed_row['include_title'];
    $includeNewsfeedImage = $feed_row['include_image'];
    $includeChannelInfo = $feed_row['include_channel'];
    $useHTMLFormatting = $feed_row['use_html'];
    $includeDescription = $feed_row['include_description'];
    $includeDetails = $feed_row['include_details'];
    $includeContent = $feed_row['include_content'];
    $includeReadMore = $feed_row['include_readmore'];
    $stripExternalImages = $feed_row['strip_images'];

    // Determine if we need to include an icon in the post, and if so
    // what type it will be.
    $icon = null;
    if ($includeIcon)
    {
        if ($isPodcast)
		{
	    	$icon = $lang['News_Podcast_Icon'];
		}
		else
        {
	    	$icon = $lang['News_RSS_Icon'];
        }
    }

    // Build the topic prefix if required.
    if (!empty($prefixTopic))
    {
        // We currently support string replacement of time and date.
        $currentDate = date($FIND_DATE_FORMAT);
        $currentTime = strftime($FIND_TIME_FORMAT);

        // Replace any special strings with required values.
        $prefixTopic = str_replace('%time', $currentTime, $prefixTopic);
        $prefixTopic = str_replace('%date', $currentDate, $prefixTopic);
    }
    else
    {
        // No prefix is supplied so make sure it is an empty string (not null)).
        $prefixTopic = '';
    }

    // Determine the maximum number of posts to process.  A configured
    // value of zero means all items in the RSS feed.
    $rss_limit = $limit;
    if (($rss_limit > count($rss_parser->items)) || ($rss_limit <= 0))	
    { 
        $rss_limit = count($rss_parser->items);
    }

    // Reset our function wide variables.
    $processed = 0;         // Number of RSS items processed.
    $debug_message = '';    // Debug message built during execution of function.

    // Loop through the list of news items processing up to the limit.
    // Insert the last item first fo the most recent is newest.
    for ($i = $rss_limit - 1; $i > -1; $i--)
    {
		// Prefix and type specific strings.
		$topic = $prefixTopic;

		// Check to see if we have a subject - some atom feeds like
		// blogspot provide an empty title.
		$title = $rss_parser->items[$i]['title'];

		if (empty($title))
		{
            // Get the first line of the description as a title.
	    	$pos = explode("\n", $rss_parser->items[$i]['description'], 2);

            if ($pos === FALSE)
	    	{
	        	$title = $rss_parser->items[$i]['description'];
	    	}
	    	else
	    	{
	        	$title = $pos[0];
	    	}

	    	if (empty($title))
	    	{
	      		continue;
	    	}
		}

		// We need to remove formatting from the subject.
		$title = stripClean($title);

		// Check to see if we need to remove leading characters.
		if ($stripTopic)
		{
	    	$title = stripBrackets($title);
		}

		// Our subjects are limited in size to 60 characters so trim if needed.
		$topic .= $title;
        $topic = trim(substr($topic, 0, 59));

		// Only proceed if topic is not already in database.
    	if (!topicAlreadyExists($topic, $forum_id))
		{
            // Initialise the userdata.
            $userdata = update_newsfeed_userdata($user_id);
                    
	    	if ($FIND_DEBUG)
	    	{
	        	print("createMultiplePosts: posting for user:<br />\n<pre>\n");
	        	print_r($userdata);
	        	print("</pre><br />\n");
				print('createMultiplePosts: new post #' .  ($processed + 1) .
						' forum_id = ' . $forum_id . 
						' Topic: "' . $topic .
						'" title: "' . $title .
						'" isPodcast=' . $isPodcast .
						' useHTMLFormatting=' . $useHTMLFormatting .
						' includeIcon=' . $includeIcon .
						' includeTitle=' . $includeTitle .
						' includeDescription=' . $includeDescription .
						' includeDetails=' . $includeDetails .
						' includeContent=' . $includeContent .
						' includeReadMore=' . $includeReadMore .
						' includeChannelInfo=' . $includeChannelInfo .
						' stripExternalImages=' . $stripExternalImages .
						' icon="' . $icon .
						'" News_Podcast_Icon="' . $lang['News_Podcast_Icon'] .
						'" News_RSS_Icon="' . $lang['News_RSS_Icon'] .
						'"<br />' . "\n");
            }

	    	// Prepare the message text.  We have two main options to
	    	// consider.
	    	if ($useHTMLFormatting)
	    	{
	    	    // Process the RSS item using HTML formatting.
                $message = addRSSItemToHTMLPost(
                        $rss_parser->items[$i],
                        $title,
                        $icon,
                        $isPodcast,
                        $includeTitle,
                        $includeDescription,
                        $includeDetails,
                        $includeContent,
                        $includeReadMore,
                        $stripExternalImages
                );
                
                // Now we need to add the channel text to the post message.
                $message .= addRSSChannelToHTMLPost(
                        $rss_parser->channel,
                        $rss_parser->channel_description,
                        $rss_parser->channel_summary,
                        $rss_parser->channel_link,
                        $rss_parser->image_link,
                        $rss_parser->image_url,
                        $includeNewsfeedImage,
                        $includeChannelInfo,
                        $stripExternalImages
                );
	    	}
	    	else
	    	{
	    	    // Process the RSS item using BBCode formatting.
                $message = addRSSItemToBBCodePost(
                        $rss_parser->items[$i],
                        $title,
                        $icon,
                        $isPodcast,
                        $includeTitle,
                        $includeDescription,
                        $includeDetails,
                        $includeContent,
                        $includeReadMore,
                        $stripExternalImages
                );
                
                // Now we need to add the channel text to the post message.
                $message .= addRSSChannelToBBCodePost(
                        $rss_parser->channel,
                        $rss_parser->channel_description,
                        $rss_parser->channel_summary,
                        $rss_parser->channel_link,
                        $rss_parser->image_link,
                        $rss_parser->image_url,
                        $includeNewsfeedImage,
                        $includeChannelInfo,
                        $stripExternalImages
                );

            }

	    	// Should we allow html, bbcode & smilies?  $useHTMLFormatting
	    	// will override board settings.
	    	$html_on = intval($board_config['allow_html'] &&
		    $userdata['user_allowhtml'] || $useHTMLFormatting);
	    	$bbcode_on = intval($board_config['allow_bbcode'] &&
		    $userdata['user_allowbbcode']);
	    	$smilies_on = intval($board_config['allow_smilies'] &&
		    $userdata['user_allowsmile']);
            $attach_sig = intval($userdata['user_attachsig']);

            // Insert our new post into the specified forum.
	    	if ($FIND_DEBUG)
	    	{
	        	print("createMultiplePosts: inserting post into database.<br />\n");
            }

            $postResult = insert_post(
                        $message, 
                        $topic, 
                        $forum_id, 
                        $user_id, 
                        $userdata['username'], 
                        $attach_sig,
                        NULL,                   // $topic_id
                        POST_NORMAL,            // $topic_type 
                        false,                  // $do_notification 
                        false,                  // $notify_user
                        0,                      // $current_time
                        'find_message_die',     // $error_die_function
                        $html_on, 
                        $bbcode_on, 
                        $smilies_on 
		    );
		    
	    	if ($FIND_DEBUG)
            {
	        	print("createMultiplePosts: insert successful - post_id=" .
				$postResult['post_id'] . " topic_id=" .
				$postResult['topic_id'] . ".<br />\n");
            }

            // Count it for our reporting to calling function.
	    	$processed++;
		}
		elseif ($FIND_DEBUG)
		{
	    	print("createMultiplePosts: post already exists - forum_id = " .
                    $forum_id . ' Topic: "' . $topic . '".<br />' . "\n");
		}

    } // For each news item.

    if ($do_sync)
    {
        include_once($phpbb_root_path . 'includes/functions_admin.'.$phpEx);
        sync('forum', $forum_id);
    }

    return ($processed);

} /* createMultiplePosts */


/***************************************************************************
 *                         createSinglePost
 *                         ----------------
 *   Description:
 *   	This function is the post handler for those RSS feeds that have a
 *      single post for all items in an RSS instance document.  Please note
 *      that the topic for a post uses the title of the first RSS item.
 *
 *   Last Updated	:	Wednesday, March 14, 2007
 *   By				:	John MacAuley - The Comic Haven
 *   E-mail			:	hacksaw@thecomichaven.com
 *
 *   Version		: 	1.2.0
 *
 *   Changes:
 *   1.2.0	- Restructured code to support single post feature.
 *   1.1	- Added code to handle differences in regular and podcast news
 *   		  feeds.
 *			- Added handling for additional HTML formatting option.
 *			- Added removal of HTML tags from the news item topic.
 *
 *   Parameters:
 *       $feed_row      - RSS feed data from FIND configuration database.
 *       $rss_parser    - Parsed RSS instance document.
 *
 *   Returns:
 *       String		- The number of RSS items processed (represents the
 *                    number of items placed in a single forum post).
 *
 ***************************************************************************/
function createSinglePost($feed_row, $rss_parser)
{
    global $phpbb_root_path, $board_config, $phpEx, $lang;    // pbpBB globals.
    global $FIND_DEBUG, $FIND_DATE_FORMAT, $FIND_TIME_FORMAT; // FIND globals.
 
    // Pull out the post configuration information.
    $forum_id = $feed_row['forum_id'];
    $limit = $feed_row['news_limit'];
    $user_id = $feed_row['user_id'];

    // These are the post formatting options.
    $prefixTopic = $feed_row['topic_prefix'];
    $stripTopic = $feed_row['strip_topic'];
    $includeIcon = $feed_row['include_icon'];
    $isPodcast = $feed_row['is_podcast'];
    $includeTitle = $feed_row['include_title'];
    $includeNewsfeedImage = $feed_row['include_image'];
    $includeChannelInfo = $feed_row['include_channel'];
    $useHTMLFormatting = $feed_row['use_html'];
    $includeDescription = $feed_row['include_description'];
    $includeDetails = $feed_row['include_details'];
    $includeContent = $feed_row['include_content'];
    $includeReadMore = $feed_row['include_readmore'];
    $stripExternalImages = $feed_row['strip_images'];

    // Determine if we need to include an icon in the post, and if so
    // what type it will be.
    $icon = null;
    if ($includeIcon)
    {
        if ($isPodcast)
        {
          $icon = $lang['News_Podcast_Icon'];
	    }
	    else
        {
	      $icon = $lang['News_RSS_Icon'];
        }
    }

    // Build the topic prefix if required.
    if (!empty($prefixTopic))
    {
        // We currently support string replacement of time and date.
        $currentDate = date($FIND_DATE_FORMAT);
        $currentTime = strftime($FIND_TIME_FORMAT);

        // Replace any special strings with required values.
        $prefixTopic = str_replace('%time', $currentTime, $prefixTopic);
        $prefixTopic = str_replace('%date', $currentDate, $prefixTopic);
    }
    else
    {
        // No prefix is supplied so make sure it is an empty string (not null)).
        $prefixTopic = '';
    }

    // Determine the maximum number of posts to process.  A configured
    // value of zero means all items in the RSS feed.
    $rss_limit = $limit;
    if (($rss_limit > count($rss_parser->items)) || ($rss_limit <= 0))	
    { 
        $rss_limit = count($rss_parser->items);
    }

    // Reset our function wide variables.
    $message = '';          // Will contain the final message added to forum.
    $processed = 0;         // Number of RSS items processed.
    $debug_message = '';    // Debug message built during execution of function.

    // Loop through the list of news items processing up to the limit.  Start
    // at first item so it is first in the post.
    for ($i = 0; $i < $rss_limit; $i++)
    {
        // Check to see if we have a subject - some atom feeds like
        // blogspot provide an empty title.
        $title = $rss_parser->items[$i]['title'];

        if (empty($title))
        {
            // Get the first line of the description as a title.
            $pos = explode("\n", $rss_parser->items[$i]['description'], 2);

            if ($pos === FALSE)
            {
	           $title = $rss_parser->items[$i]['description'];
            }
            else
            {
	           $title = $pos[0];
            }

            if (empty($title))
            {
                continue;
            }
        }

        // We need to remove formatting from the subject.
        $title = stripClean($title);

        // Check to see if we need to remove leading characters.
        if ($stripTopic)
        {
	       $title = stripBrackets($title);
        }

        // Our post topics are limited in size to 60 characters so trim if
        // needed.  We build the post topic using the title of first post.
        if ($processed == 0)
        {
            // The title of our first items is the post subject.
            $postTopic = trim(substr($prefixTopic . $title, 0, 59));;
        
            // Only proceed if topic is not already in database.
            if (topicAlreadyExists($postTopic, $forum_id))
            {
                if ($FIND_DEBUG)
                {
                    print('createSinglePost: topic already exists, forum_id=' .
                            $forum_id . ', postTopic="' . $postTopic . '".');
                }
                
                return($processed);
            }
        
            // Initialise the userdata.
            $userdata = update_newsfeed_userdata($user_id);

            // Dump the post configuration data if debugging enabled.
            if ($FIND_DEBUG)
            {
                print("createSinglePost: posting for user:<br />\n<pre>\n");
                print_r($userdata);
                print("</pre><br />\n");
                print('createSinglePost: new post #' .  ($processed + 1) .
                    ' forum_id = ' . $forum_id . 
                    ' Topic: "' . $postTopic .
                    '" title: "' . $title .
                    '" isPodcast=' . $isPodcast .
                    ' useHTMLFormatting=' . $useHTMLFormatting .
                    ' includeIcon=' . $includeIcon .
                    ' includeTitle=' . $includeTitle .
                    ' includeDescription=' . $includeDescription .
                    ' includeDetails=' . $includeDetails .
                    ' includeContent=' . $includeContent .
                    ' includeReadMore=' . $includeReadMore .
                    ' includeChannelInfo=' . $includeChannelInfo .
                    ' stripExternalImages=' . $stripExternalImages .
                    ' icon="' . $icon .
                    '" News_Podcast_Icon="' . $lang['News_Podcast_Icon'] .
                    '" News_RSS_Icon="' . $lang['News_RSS_Icon'] .
                    '"<br />' . "\n");
            }
            
        } // if $processed == 0.
        
        // Each RSS item gets added to the post message text.  We have two
        // main options to consider.
        if ($useHTMLFormatting)
        {
	    	// Process the RSS item using HTML formatting.
            $message .= addRSSItemToHTMLPost(
                            $rss_parser->items[$i],
                            $title,
                            $icon,
                            $isPodcast,
                            $includeTitle,
                            $includeDescription,
                            $includeDetails,
                            $includeContent,
                            $includeReadMore,
                            $stripExternalImages
                );
        }
        else
        {
            // Process the RSS item using BBCode formatting.
            $message .= addRSSItemToBBCodePost(
                            $rss_parser->items[$i],
                            $title,
                            $icon,
                            $isPodcast,
                            $includeTitle,
                            $includeDescription,
                            $includeDetails,
                            $includeContent,
                            $includeReadMore,
                            $stripExternalImages
                        );
        }
            
        // We added another item to the post.
        $processed++;
    }
        
    // Now we need to add the trailer to the post message.
    if ($useHTMLFormatting)
    {
        // Add RSS channel information using HTML formatting.
        $message .= addRSSChannelToHTMLPost(
                        $rss_parser->channel,
                        $rss_parser->channel_description,
                        $rss_parser->channel_summary,
                        $rss_parser->channel_link,
                        $rss_parser->image_link,
                        $rss_parser->image_url,
                        $includeNewsfeedImage,
                        $includeChannelInfo,
                        $stripExternalImages
        );
    }
    else
    {
        // Add RSS channel information using BBCode formatting.
        $message .= addRSSChannelToBBCodePost(
                        $rss_parser->channel,
                        $rss_parser->channel_description,
                        $rss_parser->channel_summary,
                        $rss_parser->channel_link,
                        $rss_parser->image_link,
                        $rss_parser->image_url,
                        $includeNewsfeedImage,
                        $includeChannelInfo,
                        $stripExternalImages
        );
    }
        
	// Should we allow html, bbcode & smilies?  $useHTMLFormatting
	// will override board settings.
	$html_on = intval($board_config['allow_html'] &&
		    $userdata['user_allowhtml'] || $useHTMLFormatting);
	$bbcode_on = intval($board_config['allow_bbcode'] &&
		    $userdata['user_allowbbcode']);
	$smilies_on = intval($board_config['allow_smilies'] &&
		    $userdata['user_allowsmile']);
        $attach_sig = intval($userdata['user_attachsig']);

        // Insert our new post into the specified forum.
	if ($FIND_DEBUG)
	{
            print("createSinglePost: inserting post (" . strlen($message) .
                    " bytes) into database.<br />\n");
        }

        $postResult = insert_post(
                    $message, 
                    $postTopic, 
                    $forum_id, 
                    $user_id, 
                    $userdata['username'], 
                    $attach_sig,
                    NULL,                   // $topic_id
                    POST_NORMAL,            // $topic_type 
                    false,                  // $do_notification 
                    false,                  // $notify_user
                    0,                      // $current_time
                    'find_message_die',     // $error_die_function
                    $html_on, 
                    $bbcode_on, 
                    $smilies_on 
	);
		    
    if ($FIND_DEBUG)
    {
        print("createSinglePost: insert successful - post_id=" .
                $postResult['post_id'] . " topic_id=" .
                $postResult['topic_id'] . ".<br />\n");
    }

    if ($do_sync)
    {
        include_once($phpbb_root_path . 'includes/functions_admin.'.$phpEx);
        sync('forum', $forum_id);
    }

    return ($processed);

} /* createSinglePost() */


/***************************************************************************
 *                         topicAlreadyExists
 *                         --------------------
 *   Author         :   netclectic - Adrian Cockburn - adrian@netclectic.com
 *   Version        :   1.0.0
 *   Created 		: 	Monday, Sept 23, 2002
 *   Last Updated   :   Monday, Feb 17, 2003
 *
 *   Description    :   This functions checks to see if a topic already exists 
 *                      with the give subject
 *
 *   Parameters     :   $topic  - the topic subject to search for
 *
 *   Returns        :   true    - if a topic with the subject exists
 *                      flase   - if a topic with the subject does not exist
 *
 ***************************************************************************/
function topicAlreadyExists( $topic, $forum_id )
{
    global $db; 

    $topicAlreadyExists = false;
    
    $sql = "SELECT topic_id FROM " . TOPICS_TABLE . " WHERE forum_id = $forum_id AND topic_title LIKE '%" . str_replace("'", "''", $topic) . "%'";
    if ( !($result = $db->sql_query($sql)) )
    {
        message_die(GENERAL_ERROR, 'Topic Already Exists', '', __LINE__, __FILE__, $sql);
    }
    $topicAlreadyExists = ($row = $db->sql_fetchrow($result));
    $db->sql_freeresult($result);
    
    return ($topicAlreadyExists);
}


/***************************************************************************
 *                         update_newsfeed_userdata
 *                         -------------------------
 *   Author         :   netclectic - Adrian Cockburn - adrian@netclectic.com
 *   Version        :   1.0.0
 *   Created 		: 	Monday, Sept 23, 2002
 *   Last Updated   :   Monday, Feb 17, 2003
 *
 *   Description    :   This functions itialises the user data and updates 
 *                      the users last visit details
 *
 *   Parameters     :   $user_id  - the id of the user
 *
 *   Returns        :   the initialise $userdata array
 *
 ***************************************************************************/
function update_newsfeed_userdata( $user_id )
{
    global $db; 

    $sql = "SELECT * FROM " . USERS_TABLE . " WHERE user_id = $user_id";
    if ( !($user_result = $db->sql_query($sql)) )
    {
    	message_die(CRITICAL_ERROR, 'Could not obtain user data from user table', '', __LINE__, __FILE__, $sql);
    }
    
    $userdata = $db->sql_fetchrow($user_result);
    init_userprefs($userdata);
    $db->sql_freeresult($user_result);
    
    // update the users last visit time
    $current_time = time();
    $sql = "UPDATE " . USERS_TABLE . " 
    	SET user_session_time = $current_time, user_session_page = " . PAGE_INDEX . ", user_lastvisit = $current_time
    	WHERE user_id = $user_id";
    	
    if (!$db->sql_query($sql))
    {
    	message_die(CRITICAL_ERROR, 'Error updating last visit time', '', __LINE__, __FILE__, $sql);
    }
    
    return($userdata);
    
} /* update_newsfeed_userdata */


/***************************************************************************
 *                      addRSSItemToBBCodePost
 *                      ----------------------
 *   Description:
 *   	This function prepares the body text of a newsfeed item that will be
 *      used in a forum post.  Only bbocde will be used by this function.
 *
 *   Last Updated   :   Wednesday, March 21, 2007
 *   By			    :	John MacAuley - The Comic Haven
 *   E-mail         :	hacksaw@thecomichaven.com
 *
 *   Parameters:
 *      $item                - An array holding news item information.
 *      $title               - Title of the news feed item.
 *      $icon                - Icon to prefix subject of post. 
 *      $isPodcast           - Post is a podcast and should be formatted as such.
 *      $includeTitle        - Include the news feed item title in the post body.
 *      $includeDescription  - Include item description in the post body.
 *      $includeDetails      - Include item details (author, etc.)in the post body.
 *      $includeContent      - Include item contents if present.
 *      $includeReadMore     - Include the read more link to original post.
 *      $stripExternalImages - Remove any external images from the post.
 *
 *   Returns:
 *   	String 		- The processed RSS item used for forum post body.
 *
 *   Changes:
 *   1.2.0  - Separated the original prepare_newsfeed_message() function
 *            into component parts to support single post feature.
 *          - Included numerous new configuration options.
 *   1.1	- Rewote original function to include new bbcode
 *   		  formatting options.
 *		    - Added new elements from rss/rdf feeds to message.
 *		    - Removed or replaced HTML code as needed from specific
 *		      elements being displayed.
 *
 ***************************************************************************/
function addRSSItemToBBCodePost(
	  $item, $title, $icon, $isPodcast,$includeTitle, $includeDescription,
	  $includeDetails, $includeContent, $includeReadMore, $stripExternalImages)
{
    global $lang; // phpBB globals.

    // These are the item fields we are interested in using. 
    $description = html2bbcode($item['description'], $stripExternalImages);
    $content = html2bbcode($item['content'], $stripExternalImages);
    $link = isaLink(stripHREF(stripClean($item['link'])));
    $commentLink = isaLink(stripHREF(stripClean($item['commentRSS'])));
    $category = stripClean($item['category']);
    $pubDate = stripClean($item['pubDate']);
    $guid = stripClean($item['guid']);
    $duration = stripClean($item['duration']);
    $author = stripClean($item['author']);
    $isPermaLink = $item['isPermaLink'];
    $enclosure = $item['enclosure'];
    $sourceURL = isaLink(stripHREF(stripClean($item['enclosureURL'])));
    $sourceLength = $item['enclosureLength'];
    $sourceType = $item['enclosureType'];

    $message = ''; 

    // Start message with the icon if available.
    if (!empty($icon))
    {
	    // If we have a source URL use it as it may link to media.
	    if (!empty($sourceURL))
	    {
		    $message .= '[url=' . $sourceURL . '][img]' . $icon . '[/img][/url] ';
	    }
	    // If there is no source URL use the article link instead.
	    else if (!empty($link))
	    {
		    $message .= '[url=' . $link . '][img]' . $icon . '[/img][/url] ';
	    }
	    // If there is no link then just display the icon.
	    else
	    {
		    $message .= '[img]' . $icon . '[/img] ';
	    }
    }

    // Now output the full title in the body of text.
    if ($includeTitle && !empty($title))
    {
        if (!empty($link))
        {
            $message .= "[size=16][b][url=" . $link . "]" . $title .
                "[/url][/b][/size]\n";
        }
        else
        {
            $message .= "[size=16][b]" . $title . "[/b][/size]\n";
        }
    }
    elseif (!empty($icon))
    {
        $message .= "\n";
    }

    // Now we add the item description.
    if ($includeDescription && !empty($description))
    {
	    $message .= $description . "\n\n";
    }
    
    // Insert the author and duration information if needed.
    if ($includeDetails)
    {
        if (!empty($author))
        {
            $message .= "[b]" . $lang['News_Author'] . "[/b] " . $author . "\n";
        }

        if (!empty($duration))
        {
            $message .= "[b]" . $lang['News_Duration'] . "[/b] " . $duration . "\n";
        }

        // Check to see if a category and publish date data have been provided.
        if (!empty($category))
        {
            $message .= "[b]" . $lang['News_Category'] . "[/b] " . $category . "\n";
        }

        if (!empty($pubDate))
        {
            $message .= "[b]" . $lang['News_Publish_Date'] . "[/b] " . $pubDate . "\n";
        }

        // Place direct download link and file information.
        if (!empty($sourceURL))
        {
            $pos = strrpos($sourceURL, "/");
            
            if ($pos === false)
            {
                $pos = 0;
            }
            else
            {
                $pos = $pos + 1;
            }

            $message .= "[b]" . $lang['News_Direct_Download'] . "[/b] " . "[url=" .
                $sourceURL . "][b]" . substr($sourceURL, $pos) . "[/b][/url]";
    
            if (!empty($sourceLength))
            {
                $message .= " [i](" . $sourceLength . " " . $lang['News_Bytes'] .
                    " " . $sourceType . ")[/i]";
            }

            $message .= "\n";
        }
    }

    // Now we add the content if provided.
    if ($includeContent && !empty($content))
    {
        $message .= "\n" . $content . "\n";
    }

    if ($includeReadMore)
    {
      $tempMessage = "";
      if (!empty($link))
      {
          $tempMessage .= '[url=' . $link . '][i]' . $lang['News_Read_More'] .
                '[/i][/url]';
      }

      if (!empty($commentLink))
      {
          $tempMessage .= ' - ' . '[url=' . $commentLink . '][i]' .
                $lang['News_Read_Comments'] . '[/i][/url]';
      }

      if (!empty($tempMessage))
      {
        $message .= "\n" . $tempMessage . "\n";
      }
    }

    $message = cleanWhiteSpace($message) . "\n";

    return($message);

} /* addRSSItemToBBCodePost() */


/***************************************************************************
 *                      addRSSChannelToBBCodePost
 *                      -------------------------
 *   Description:
 *   	This function prepares the channel information text of a newsfeed
 *      that will be appended to the end of the forum post.  Only bbocde
 *      will be used by this function.
 *
 *   Last Updated   :   Wednesday, March 21, 2007
 *   By			    :	John MacAuley - The Comic Haven
 *   E-mail         :	hacksaw@thecomichaven.com
 *
 *   Parameters:
 *       $channel 		        - Channel naming information.
 *       $channel_description 	- Short description of channel.
 *       $channel_summary       - Additional channel information.
 *       $channel_link          - URL to channel source.
 *       $image_link            - Hyperlink for image when selected.
 *       $image_url             - Location of image to display.
 *       $includeChannelInfo 	- Should channel information be included?
 *       $includeNewsfeedImage 	- Should the channel image be displayed?
 *
 *   Returns:
 *   	String 		- The processed RSS channel used for forum post body.
 *
 *   Changes:
 *   1.2.0  - Separated the original prepare_newsfeed_message() function
 *            into component parts to support single post feature.
 *   1.1	- Rewote original function to include new bbcode
 *   		  formatting options.
 *		    - Added new elements from rss/rdf feeds to message.
 *		    - Removed or replaced HTML code as needed from specific
 *		      elements being displayed.
 *
 ***************************************************************************/
function addRSSChannelToBBCodePost(
	  $channel, $channel_description, $channel_summary, $channel_link,
      $image_link, $image_url, $includeNewsfeedImage, $includeChannelInfo,
      $stripExternalImages)
{
    global $lang; // phpBB globals.

    $image_link = isaLink(stripHREF(stripClean($image_link)));
    $image_url = isaLink(stripImageURL(stripClean($image_url)));
    $channel_description = html2bbcode($channel_description, $stripExternalImages);
    $channel_summary = html2bbcode($channel_summary, $stripExternalImages);

    $message = '';
    
    // Should we include the channel info for this newsfeed    
    if ($includeChannelInfo)
    {
        if (!empty($channel))
        {
            $message .= "[b]" . $lang['News_Source'] . "[/b]";
  
            if (!empty($channel_link))
            {
                $message .= "[url=" . $channel_link . "]" . $channel . "[/url]\n";
            }
            else
            {
                $message .= $channel . "\n";
            }
        }

        if (!empty($channel_description))
        {
            $message .= "[b]" . $lang['News_Description'] . "[/b][size=10]".
                $channel_description . "[/size]\n";
        }

        if (!empty($channel_summary))
        {
            $message .= "[b]" . $lang['News_Summary'] . "[/b] [size=10]". 
                    $channel_summary . "[/size]\n";
        }
    }
    
    //Should we include any image info for this newsfeed
    if ($includeNewsfeedImage && !empty($image_url))
    {
        if (!empty($image_link))
        {
            $message .= "[url=" . $image_link . "][img]" . $image_url .
                    "[/img][/url]\n";
        }
        else
        {
            $message .= "[img]" . $image_url . "[/img]\n";
        }
    }

    $message = cleanWhiteSpace($message);

    return($message);

} /* addRSSChannelToBBCodePost() */


/***************************************************************************
 *                      addRSSItemToHTMLPost
 *                      --------------------
 *   Description:
 *   	This function prepares the body text of a newsfeed item that will be
 *      used in a forum post.  Only HTML will be used by this function.
 *
 *   Last Updated   :   Wednesday, March 21, 2007
 *   By			    :	John MacAuley - The Comic Haven
 *   E-mail         :	hacksaw@thecomichaven.com
 *
 *   Parameters:
 *      $item                - An array holding news item information.
 *      $title               - Title of the news feed item.
 *      $icon                - Icon to prefix subject of post. 
 *      $isPodcast           - Post is a podcast and should be formatted as such.
 *      $includeTitle        - Include the news feed item title in the post body.
 *      $includeDescription  - Include item description in the post body.
 *      $includeDetails      - Include item details (author, etc.)in the post body.
 *      $includeContent      - Include item contents if present.
 *      $includeReadMore     - Include the read more link to original post.
 *      $stripExternalImages - Remove any external images from the post.
 *
 *   Returns:
 *      String      - The HTML formatted message.
 *
 *   1.2.0  - Separated the original prepare_html_message() function
 *            into component parts to support single post feature.
 *          - Included numerous new configuration options.
 *   1.1	- Created.
 *
 ***************************************************************************/
function addRSSItemToHTMLPost(
	  $item, $title, $icon, $isPodcast,$includeTitle, $includeDescription,
	  $includeDetails, $includeContent, $includeReadMore, $stripExternalImages)
{
    global $lang; // phpBB globals.

    // These are the item fields we are interested in using.  Replace bbcode
    // with html in the off chance there is any.
    $description = bbcode2html($item['description'], $stripExternalImages);
    $content = bbcode2html($item['content'], $stripExternalImages);
    $link = isaLink(stripHREF(stripClean($item['link'])));
    $commentLink = isaLink(stripHREF(stripClean($item['commentRSS'])));
    $category = stripClean($item['category']);
    $pubDate = stripClean($item['pubDate']);
    $guid = stripClean($item['guid']);
    $duration = stripClean($item['duration']);
    $author = stripClean($item['author']);
    $isPermaLink = $item['isPermaLink'];
    $enclosure = $item['enclosure'];
    $sourceURL = isaLink(stripHREF(stripClean($item['enclosureURL'])));
    $sourceLength = $item['enclosureLength'];
    $sourceType = $item['enclosureType'];

    // Frame the contents in a table.
    $message = '';
    $temp_message = '';

    // Start message with the podcast icon and title in a row.
    $colspan = 0;
    if (!empty($icon))
    {
        $temp_message .= '<td align="left" valign="middle">';

        // If we have a source URL use it as it may link to media.
        if (!empty($sourceURL))
	    {
            $temp_message .= '<a href="' . $sourceURL . 
                    '" target="_blank"><img src="' . $icon . '" /></a>';
	    }
        // If there is no source URL use the article link instead.
        elseif (!empty($link))
        {
            $temp_message .= '<a href="' . $link .
                    '" target="_blank"><img src="' . $icon . '" /></a>';
        }
        // If there is no link then just display the icon.
        else
        {
            $temp_message .= '<img src="' . $icon . '" />';
        }

        $temp_message .= '</td>';
        $colspan++;
    }

    // Now output the title.
    if ($includeTitle && !empty($title))
    {

        $temp_message .= '<td align="left" valign="middle" width="100%"><font size="+1"><b>';

        if (!empty($link))
        {
            $temp_message .= '<a href="' . $link . '" target="_blank">' . $title . '</a>';
        }
        else
        {
            $temp_message .= $title;
        }

        $temp_message .= '</b></font></td>';
        $colspan++;
    }

    $temp_message2 .= '';

    if ($includeDescription && !empty($description))
    {
        if ($colspan > 1)
        {
            $colspanString = ' colspan="' . $colspan . '" ';
        }
        else
        {
            $colspanString = ' ';
        }

        $temp_message2 .= '<tr><td align="left" valign="top"' .
                $colspanString . 'class="postbody">' .
                $description . '</td></tr>';
    }

    // Close the description table.
    if (!empty($temp_message) || !empty($temp_message2))
    {
        $message .= '<table width="99%" cellspacing="2" cellpadding="2" border="0" align="center"><tbody>';
        if (!empty($temp_message))
        {
            $message .= '<tr>';
            $message .= $temp_message;
            $message .= '</tr>';
        }

        $message .= $temp_message2;
        $message .= '</tbody></table><br />';
    }

    // Include the post details typically associated with podcasts.
    if ($includeDetails)
    {
        // The podcast table may be optional.
        $temp_message = "";

        // Insert the author information.
        if (!empty($author))
        {
            $temp_message .=
                    '<tr><td align="left" width="120" class="postbody"><b>' .
                    $lang['News_Author'] .
                    '</b></td><td align="left" class="postbody">' .
                    $author . '</td></tr>';
        }

        // Insert the duration information.
        if (!empty($duration))
        {
            $temp_message .=
                    '<tr><td align="left" width="120" class="postbody"><b>' .
                    $lang['News_Duration'] .
                    '</b></td><td align="left" class="postbody">' .
                    $duration . '</td></tr>';
        }

        // Check to see if a category and publish date data have been provided.
        if (!empty($category))
        {
            $temp_message .=
                    '<tr><td align="left" width="120" class="postbody"><b>' .
                    $lang['News_Category'] .
                    '</b></td><td align="left" class="postbody">' .
                    $category . '</td></tr>';
        }

        if (!empty($pubDate))
        {
            $temp_message .=
                    '<tr><td align="left" width="120" class="postbody"><b>' .
                    $lang['News_Publish_Date'] .
                    '</b></td><td align="left" class="postbody">' .
                    $pubDate . '</td></tr>';
        }

        // Place direct download link and file information.
        if (!empty($sourceURL))
        {
            $pos = strrpos($sourceURL, "/");
            if ($pos === false)
            {
                $pos = 0;
            }
            else
            {
                $pos = $pos + 1;
            }

            $temp_message .=
                    '<tr><td align="left" width="120" class="postbody"><b>' .
                    $lang['News_Direct_Download'] .
                    '</b></td><td align="left" class="postbody">' .
                    '<a href="' . $sourceURL . '" target="_blank"><b>' .
                    substr($sourceURL, $pos) . '</b></a>';

            if (!empty($sourceLength))
            {
                $temp_message .= ' <i>(' . $sourceLength . ' ' .
                        $lang['News_Bytes'] . ' ' . $sourceType . ')</i>';
            }

            $temp_message .= '</td></tr>';
        }

        // Fill in podcast table if present. 
        if (!empty($temp_message))
        {
            $message .= '<table width="99%" cellspacing="2" cellpadding="0" border="0" align="center"><tbody>';
            $message .= $temp_message;
            $message .= '</tbody></table><br />';
        }
    }

    // The content table is optional.
    if ($includeContent && !empty($content))
    {
        $message .= '<table width="99%" cellspacing="2" cellpadding="0" border="0" align="center"><tbody>';
        $message .= '<tr><td align="left">' . $content . '</td></tr>';
        $message .= '</tbody></table><br />';
    }

    // The "Read More" links are optional.
    if ($includeReadMore)
    {
        $temp_message = "";

        if (!empty($link))
        {
            $temp_message .= '<a href="' . $link . '" target="_blank"><i>' .
                    $lang['News_Read_More'] . '</i></a>';
        }

        if (!empty($commentLink))
        {
            if (!empty($link))
            {
                $temp_message .= ' - ';
            }

            $temp_message .= '<a href="' . $commentLink .
                    '" target="_blank"><i>' . $lang['News_Read_Comments'] .
                    '</i></a>';
        }
	    
        if (!empty($temp_message))
        {
            $message .= '<table width="99%" cellspacing="2" cellpadding="0" border="0" align="center"><tbody>';
            $message .= '<tr><td align="left" class="postbody">';
            $message .= '[' . $temp_message . ']</td></tr>';
            $message .= '</tbody></table><br />';
        }
    }
    
    return($message);

} /* addRSSItemToHTMLPost() */


/***************************************************************************
 *                      addRSSChannelToHTMLPost
 *                      -----------------------
 *   Description:
 *   	This function prepares the channel information text of a newsfeed
 *      that will be appended to the end of the forum post.  Only bbocde
 *      will be used by this function.
 *
 *   Last Updated   :   Wednesday, March 21, 2007
 *   By			    :	John MacAuley - The Comic Haven
 *   E-mail         :	hacksaw@thecomichaven.com
 *
 *   Parameters:
 *       $channel 		        - Channel naming information.
 *       $channel_description 	- Short description of channel.
 *       $channel_summary       - Additional channel information.
 *       $channel_link          - URL to channel source.
 *       $image_link            - Hyperlink for image when selected.
 *       $image_url             - Location of image to display.
 *       $includeChannelInfo 	- Should channel information be included?
 *       $includeNewsfeedImage 	- Should the channel image be displayed?
 *
 *   Returns:
 *   	String 		- The processed RSS channel used for forum post body.
 *
 *   Changes:
 *   1.2.0  - Separated the original prepare_html_message() function
 *            into component parts to support single post feature.
 *   1.1	- Created.
 *
 ***************************************************************************/
function addRSSChannelToHTMLPost(
	  $channel, $channel_description, $channel_summary, $channel_link,
      $image_link, $image_url, $includeNewsfeedImage, $includeChannelInfo,
      $stripExternalImages)
{
    global $lang; 

    // These are the item fields we are interested in using.  Replace bbcode
    // with html in the off chance there is any.
    $image_link = isaLink(stripHREF(stripClean($image_link)));
    $image_url = isaLink(stripClean($image_url));
    $channel_description = bbcode2html($channel_description, $stripExternalImages);
    $channel_summary = bbcode2html($channel_summary, $stripExternalImages);
    
    // Include any image info for this newsfeed.
    $image_message = '';
    if ($includeNewsfeedImage && !empty($image_url))
    {
        $image_message .= '<td %rowspan% valign="top">';
        
        if (!empty($image_link))
        {
            $image_message .= '<a href="' . $image_link .
                '" target="_blank"><img src="' . $image_url .
                '" /></a></td>';
        }
        else
        {
            $image_message .= '<img src="' . $image_url .
                '" width="120" /></td>';            
        }
    }

    // Include the channel info for this newsfeed.
    $temp_message = '';
    $rows = 0;
    if ($includeChannelInfo)
    {
        if (!empty($channel))
        {
            $temp_message .=
                '<tr><td align="left" valign="top" width="120" class="postbody"><b>' .
                $lang['News_Source'] . '</b></td>';
            $temp_message .= '<td align="left" valign="top" class="postbody"><a href="' .
                $channel_link . '" target="_blank">' . $channel .
                '</a></td>';
                
            if (!empty($image_message))
            {
                $temp_message .= $image_message;
            }
            
            $temp_message .= '</tr>';
            $rows++;
        }

        if (!empty($channel_description))
        {
            $temp_message .=
                '<tr><td align="left" valign="top" width="120" class="postbody">'.
                '<b>' . $lang['News_Description'] .
                '</b></td><td align="left" valign="top" class="postbody">'. $channel_description .
                '</td>';
                
            if ($rows == 0 && !empty($image_message))
            {
                $temp_message .= $image_message;
            }
            
            $temp_message .= '</tr>';
            $rows++;
        }

        if (!empty($channel_summary))
        {
            $temp_message .=
                '<td align="left" valign="top" width="120" class="postbody">' .
                '<b>' . $lang['News_Summary'] .
                '</b></td><td align="left" valign="top" class="postbody">'. $channel_summary .
                '</td>';

            if ($rows == 0 && !empty($image_message))
            {
                $temp_message .= $image_message;
            }
            
            $temp_message .= '</tr>';
            $rows++;
        }

        if ($rows > 0)
        {
            $message = '<table width="99%" cellspacing="2" cellpadding="0" border="0" align="center"><tbody>';
            $message .= str_replace('%rowspan%', 'rowspan="' . $rows . '"', $temp_message);
            $message .= '</tbody></table><br />';
        }
        else
        {
            $message = '<table width="99%" cellspacing="2" cellpadding="0" border="0" align="center"><tbody>';
            $message .= str_replace('%rowspan%', '', $image_message);
            $message .= '</tbody></table><br />';
        }
    }
    
    return($message);

} /* addRSSChannelToHTMLPost() */


/***************************************************************************
 *                      find_message_die
 *                      ----------------
 *   Description:
 *   	This function is called when a critical error is encountered within
 *      the FIND logic that requires processing to terminate.  A debug
 *      message is generated if enabled, then the phpBB message_die()
 *      function is called to terminate processing
 *
 *   Last Updated   :   Wednesday, March 21, 2007
 *   By			    :	John MacAuley - The Comic Haven
 *   E-mail         :	hacksaw@thecomichaven.com
 *
 *   Parameters:
 *       $errorType 	        - Type of error encountered during processing.
 *       $errText            	- Error text associated with the failure.
 *       $crap                  - Unused but needed by message_die().
 *       $line                  - Source code line that encountered failure.
 *       $file                  - File name that failure occured in.
 *       $sql                   - The SQL statement that caused error if applicable.
 *
 *   Returns:
 *   	Does not return.
 *
 *   Changes:
 *   1.2.0  - Updated documentation
 *
 ***************************************************************************/
function find_message_die($errorType, $errText, $crap, $line, $file, $sql)
{
    global $FIND_DEBUG;

    if ($FIND_DEBUG)
    {
        print("find_message_die: errorType=" . $errorType . " errorText=" .
            $errorText . " crap=" . $crap . " line=" . $line . " file=" .
            $file . " sql=" . $sql . ".<br />\n");
    }

    message_die($errorType, $errText, $crap, $line, $file, $sql);

} /* find_message_die() */

?>
