<?php
/***************************************************************************
 *                              find_rssParser.php
 *                              ------------------
 *   Description:
 *   	This module contains the xml parsing functions for removing news
 *   	item specific information from the rdf/rss feed.
 *
 *   Last Updated	:	Wednesday, March 14, 2007
 *   By	            :	John MacAuley - The Comic Haven
 *   E-mail         :	hacksaw@thecomichaven.com
 *
 *   Version		: 	1.2.0
 *
 *   Changes:
 *   1.2.0  - Added support for the windows1252 character set.
 *          - Added support for forced encoding type to handle case where
 *            the encoding type in the RSS feed is incorrect. 
 *   1.1	- Added additional tag support including ATOM and iTunes schema
 *   		  for podcasts.
 *          - Added pre-filtering of special characters that are not handled
 *            by the xml parser.
 *          - Added support for CURL retrieval of RSS feed.
 *
 ***************************************************************************/

// This rssParser will take a url to an RSS feed and instantiate an xml parser
// to read it.  It should be noted that some RSS feeds are including character
// encodings that do not match the encoding specified in the file header.  In
// these cases some characters may be replaced with alternative characters
// by the parser.
//
// The channel details will be stored in three variable, $channel, 
// $channel_description & $channel_link. The news items (everything enclosed
// between <item> elements) from the rss feed will be stored in the $items
// array using the following member strings:
// 
//    'title'		- the list of item titles from the <title> elements.
//    'description'	- the list of item descriptions from the <description>
//			  elements.
//    'link'		- the list of item links from the <link> elements.
// 			  elements.
//    'content'		- item content data from the <content:encoded>
//    			  element.
//    'guid'		- the list of globally unique identifiers for each
// 			  item from the <guid> element.  This is inconsistently
// 			  used but could contain a direct URL to the item such
// 			  as in links, a title, or a unique string.
//    'pubdate'		- contains the published date of the entry from the
//			  <pubDate> element.
//    'category'	- contains the category information of the entry from
//			  the <categroy> element.
//    'enclosure'	- data contained in the <enclosures> element.  When
//			  used for podcasts this will contain the audio
//			  information and a URL to the source held as
//			  attributes of the element.
//    'enclosureURL'	- URL attribute from enclosure element.
//    'enclosureLength' - length attribute from enclosure element.
//    'enclosureType'	- type attribute from enclosure element.
//    'author'		- contains the author of the entry from the
//			  <itunes:author> element, the <dc:creator>
//			  element, or the <atom:name> element.
//    'email'		- contains the email of the author from the
//			  <atom:email> element.
//    'duration'	- contains the length of audio track from the
//			  <itunes:duration> element.
//    'commentRss'	- URL link to item comments if any.
//
class rssParser 
{
	// private - an _ (underscore) will hide these fields from public view
	//	     effectivly making them private fields.
	
	var $_insideitem = false;        // We are inside an item element.
	var $_insidechannel = false;     // We are inside a channel element.
	var $_insideimage = false;       // We are inside an image element.
	var $_tag = '';                  // Tag we are currently parsing.

	var $_isPermaLink = false;       // Is the GUID element a permalink.
	var $_enclosure = array();       // Attributes for the enclosure element.
	var $_enclosurePresent = false;  // An enclosure element was encountered.

    	var $_item = array();            // Buffer of elements for current item.

	var $_image_url='';              // Channel image attributes.
	var $_image_link='';
	var $_image_width='0';
	var $_image_height='0';
	var $_image_title='';

	var $_channel='';                // Channel attributes.
	var $_channel_description='';
	var $_channel_link='';
	var $_channel_summary='';

	var $_xml_parser = null;
	var $_fp;
	var $_use_curl = false;          // Use curl library for transfer.
	var $_debug = false;             // Enable debug tracing.

	// public
	var $image_url='';               // Channel image attributes.
	var $image_link='';
	var $image_width='0';
	var $image_height='0';
	var $image_title='';
    
	var $channel='';                 // Channel attributes.
	var $channel_description='';
	var $channel_link='';
	var $channel_summary='';
	
    	var $items = array();            // Array containing all news items.
	
	var $error_msg='';		 // Error message is problem encountered.

	
	// our class constructor
	function rssParser($curl, $debug)
	{
	    $this->_use_curl = $curl;
	    $this->_debug = $debug;
	}
	
	// our class destructor (kind of)
	function destroy()
	{
	    // destroy our xml parser.
	    if ($this->_xml_parser != null)
	    {
	       xml_parser_free($this->_xml_parser);
	       $this->_xml_parser = null;
	    }
	}

    // This function converts special character encodings to standard
    // characters.
    function _replaceSpecial($string)
    {
        //
	    // It should be noted that some RSS feeds are not properly including
	    // special character encodings.  In these cases some characters may
        // be replaced with alternative characters by the xml parser, and
	    // so we must convert these characters before handing them off to
	    // the xml parser.  Additional characters can be added as needed.
        //
	    $search = array(
            '@[\n\r]*<\?[ ]*phpxml@si',
	        '@&#8211;@si',
	        '@&#8212;@si',
            '@&#8216;@si',
	        '@&#8217;@si',
	        '@&#8220;@si',                     
	        '@&#8221;@si',
	        '@&#39;@si',
	        '@&#34;@si',
	        '@&#8230;@si',
	        '@&#8242;@si',
            '@&#38;|&#038;|&#0038;@si',
            '@\x9d@si'
        );
        
	    $replace = array(
            '<?xml',
	        '-',
	        '--',
                '\'',
	        '\'',
	        '"',                     
	        '"',
	        '\'',
	        '"',
	        '...',
	        '\'',
            '&amp;',
            '\''
        );

	    if ($this->_debug)
	    {
	        print("rssParser._replaceSpecial: converting special characters.<br />\n");
	    }


            $text = preg_replace($search, $replace, $string);
        
            return($text);
        
        } /* _replaceSpecial() */


	// Replace non-standard UTF-8 characters.
	function _utf8_replace($string)
	{
	    $badchr = array(
	        "\xe2\x80\x2d",
	        "\xe2\x80\xa6",  // ellipsis
	        "\xe2\x80\x93",  // long dash
	        "\xe2\x80\x94",  // long dash
	        "\xe2\x80\x98",  // single quote opening
	        "\xe2\x80\x99",  // single quote closing
	        "\xe2\x80\x9c",  // double quote opening
	        "\xe2\x80\x9d",  // double quote closing
	        "\xe2\x80\xa2",	// dot used for bullet points
	        "\xe2\x80\x99"	// apostrophe
	    );

    	    $goodchr = array(
		'-',
		'...',
       		'-',
       		'-',
       		"'",
       		"'",
       		'"',
       		'"',
       		'*',
       		"'"
       	    );

    	    $string = str_replace($badchr, $goodchr, $string);

    	    return($string);

	} /* _utf8_replace() */


	// Replace non-standard UTF-8 characters.
	function _windows1252_replace($string)
	{
	    $badchr = array(
	        "\x80", 	// EURO SIGN
	        "\x81",  	// UNDEFINED
	        "\x82",  	// SINGLE LOW-9 QUOTATION MARK
	        "\x83", 	// LATIN SMALL LETTER F WITH HOOK
	        "\x84", 	// DOUBLE LOW-9 QUOTATION MARK
	        "\x85", 	// HORIZONTAL ELLIPSIS
	        "\x86", 	// DAGGER
	        "\x87", 	// DOUBLE DAGGER
	        "\x88",		// MODIFIER LETTER CIRCUMFLEX ACCENT
            "\x89",		// PER MILLE SIGN
		    "\x8A",		// LATIN CAPITAL LETTER S WITH CARON
		    "\x8B",		// SINGLE LEFT-POINTING ANGLE QUOTATION MARK
		    "\x8C",		// LATIN CAPITAL LIGATURE OE
		    "\x8D",		// UNDEFINED
		    "\x8E",		// LATIN CAPITAL LETTER Z WITH CARON
		    "\x8F",		// UNDEFINED 
		    "\x90",		// UNDEFINED
		    "\x91",		// LEFT SINGLE QUOTATION MARK
		    "\x92",		// RIGHT SINGLE QUOTATION MARK
		    "\x93",		// LEFT DOUBLE QUOTATION MARK
		    "\x94",		// RIGHT DOUBLE QUOTATION MARK
		    "\x95",		// BULLET
		    "\x96",		// EN DASH
		    "\x97",		// EM DASH
		    "\x98",		// SMALL TILDE
		    "\x99",		// TRADE MARK SIGN
		    "\x9A",		// LATIN SMALL LETTER S WITH CARON
		    "\x9B",		// SINGLE RIGHT-POINTING ANGLE QUOTATION MARK
		    "\x9C",		// LATIN SMALL LIGATURE OE
		    "\x9D",		// UNDEFINED
		    "\x9E",		// LATIN SMALL LETTER Z WITH CARON
		    "\x9F" 		// LATIN CAPITAL LETTER Y WITH DIAERESIS
	    );

    	$goodchr = array(
	        "&#8364;", 	// EURO SIGN
	        "",  		// UNDEFINED
	        "&#8218;",  	// SINGLE LOW-9 QUOTATION MARK
	        "&#0402;", 	// LATIN SMALL LETTER F WITH HOOK
	        "&#8222;", 	// DOUBLE LOW-9 QUOTATION MARK
	        "&#8230;", 	// HORIZONTAL ELLIPSIS
	        "&#8224;", 	// DAGGER
	        "&#8225;", 	// DOUBLE DAGGER
	        "&#0710;",	// MODIFIER LETTER CIRCUMFLEX ACCENT
		    "&#8240;",	// PER MILLE SIGN
		    "&#0352;",	// LATIN CAPITAL LETTER S WITH CARON
		    "&#8249;",	// SINGLE LEFT-POINTING ANGLE QUOTATION MARK
		    "&#0338;",	// LATIN CAPITAL LIGATURE OE
		    "",		// UNDEFINED
		    "&#0381;",	// LATIN CAPITAL LETTER Z WITH CARON
		    "",		// UNDEFINED 
		    "",		// UNDEFINED
		    "&#8216;",	// LEFT SINGLE QUOTATION MARK
		    "&#8217;",	// RIGHT SINGLE QUOTATION MARK
		    "&#8220;",	// LEFT DOUBLE QUOTATION MARK
		    "&#8221;",	// RIGHT DOUBLE QUOTATION MARK
		    "&#8226;",	// BULLET
		    "&#8211;",	// EN DASH
		    "&#8212;",	// EM DASH
		    "&#0732;",	// SMALL TILDE
		    "&#8482;",	// TRADE MARK SIGN
		    "&#0353;",	// LATIN SMALL LETTER S WITH CARON
		    "&#8250;",	// SINGLE RIGHT-POINTING ANGLE QUOTATION MARK
		    "&#0339;",	// LATIN SMALL LIGATURE OE
		    "",		// UNDEFINED
		    "&#0382;",	// LATIN SMALL LETTER Z WITH CARON
		    "&#0376;" 	// LATIN CAPITAL LETTER Y WITH DIAERESIS
       	);

    	$string = str_replace($badchr, $goodchr, $string);

   	    return($string);

	} /* _windows1252_replace() */


	// The supported encodings are ISO-8859-1, UTF-8 and US-ASCII.
	function _getEncodingType($string)
	{
	    // Default to UTF-8.
	    $result = "UTF-8";

	    // Find the end of the xml header element.
	    $pos = strpos($string, "?>");
	    if ($pos === FALSE)
	    {
		return($result);
	    }

	    // Find the encoding attribute.
	    $string = substr($string, 0, $pos);
	    $string = strtoupper($string);
	    $pos = strpos($string, "ENCODING=");

	    if ($pos === FALSE)
	    {
	        if ($this->_debug)
	        {
                    print("rssParser._getEncodingType: could not find encoding in stream.<br />\n");
                }
	        return($result);
	    }

	    $pos = $pos + strlen("ENCODING=");
	    $string = substr($string, $pos);

	    // Determine encoding - a substring search should do...
	    if (!(strpos($string, "UTF-8") === FALSE))
	    {
                $result = "UTF-8";
	    }
            elseif (!(strpos($string, "ISO-8859-1") === FALSE))
	    {
                $result = "ISO-8859-1";
	    }
            elseif (!(strpos($string, "US-ASCII") === FALSE))
	    {
                $result = "US-ASCII";
	    }
            elseif (!(strpos($string, "WINDOWS-1252") === FALSE))
	    {
                $result = "WINDOWS-1252";
	    }

	    if ($this->_debug)
            {
                print("rssParser._getEncodingType: stream encoding type = " . $result . ".<br />\n");
            }

	    return($result);

        } /* _getEncodingType() */


	// Retrieve and parse the xml document.
	function parse($rss_url, $encodingType = 'Detect')
	{
	    $prev_error_reporting = error_reporting();
	    error_reporting(E_ERROR);
		
	    $data = '';

	    // Use curl to transfer data if needed.
	    if ($this->_use_curl)
	    {
		if ($this->_debug)
		{
		    print("rssParser.parse: using curl to retrieve " . $rss_url . "<br />\n");
		}

	        // We are restricted to reading all the contents in a single go.
                $this->_fp = curl_init();
                curl_setopt($this->_fp, CURLOPT_URL, $rss_url);
                curl_setopt($this->_fp, CURLOPT_HEADER, 0);
                curl_setopt($this->_fp, CURLOPT_USERAGENT, $_SERVER['HTTP_USER_AGENT']);
                curl_setopt($this->_fp, CURLOPT_FOLLOWLOCATION, 1);
		curl_setopt($this->_fp, CURLOPT_RETURNTRANSFER, 1);

                $data = curl_exec($this->_fp);

		$errno = curl_errno($this->_fp);
		curl_close($this->_fp);

		if ($errno)
		{
		    if ($this->_debug)
		    {
		        print("rssParser.parse: curl error " . $errno . "<br />\n");
		    }

                    return(false);
                }
            }
	    // Use fopen() instead.
	    else
	    {
		if ($this->_debug)
		{
		    print("rssParser.parse: using fopen to retrieve " . $rss_url . "<br />\n");
		}

		// Retrieve the data from the given url.
		if ($this->_fp = @fopen($rss_url, 'r'))
		{
                    $data = '';
		    while (!feof($this->_fp))
		    {
			$data .= fread($this->_fp, 4096);
		    }

		    fclose($this->_fp);
		}
		else
		{
		    if ($this->_debug)
		    {
		        print("rssParser.parse: Error - fopen failed.<br />\n");
		    }

		    return(false);
		}
	    }


	    // Determine the encoding type of the data feed.
	    if ($encodingType == 'Detect')
	    {
	      $encodingType = $this->_getEncodingType($data);
	    }
	    elseif ($this->_debug)
	    {
              print("rssParser.parse: Manually setting encoding to " . $encodingType . ".<br />\n");
	    }

	    // Windows-1252 is not supported by the XML parser.  Replace those
	    // characters not supported in other character sets and convert it
	    // to UTF-8.
	    if ($encodingType == 'WINDOWS-1252')
            {
	        $data = $this->_windows1252_replace($data);
                $encodingType = 'UTF-8';
	    }

	    if ($encodingType == 'UTF-8')
	    {
		$data = $this->_utf8_replace($data);
            }

	    // Title parsing doesn't seem to handle some special characters
	    // correctly.  Update this function to convert additional 
	    // characters as needed.
	    $data = $this->_replaceSpecial($data);

	    // Make sure we have not already allocated a parser.
	    if ($this->_xml_parser != null)
	    {
	        if ($this->_debug)
	        {
		    print("rssParser.parse: Error - xml parser already initialized.<br />\n");
                }
                return(false);
            }

	    // Instantiate an xml parser and setup the reserved events.
            $this->_xml_parser = xml_parser_create($encodingType);
	    xml_set_object($this->_xml_parser, &$this);
	    xml_set_element_handler($this->_xml_parser, 'startElement', 'endElement');
	    xml_set_character_data_handler($this->_xml_parser, 'characterData');
	    xml_parser_set_option($this->_xml_parser, XML_OPTION_TARGET_ENCODING, "ISO-8859-1");

	    if ($this->_debug)
	    {
		    print("rssParser.parse: xml parsing rss input.<br />\n");
            }

            // parse our xml data.
	    if (xml_parse($this->_xml_parser, $data, true) == 0)
	    {
	      printf("XML error: %s at line %d column %d.\n", 
                  xml_error_string(xml_get_error_code($this->_xml_parser)), 
		  xml_get_current_line_number($this->_xml_parser),
		  xml_get_current_column_number($this->_xml_parser) + 1);
	      return(0);
            }

            if ($this->_debug)
            {
		    print("rssParser.parse: xml parsing complete.<br />\n");
            }

	    error_reporting($prev_error_reporting);

	    // Destroy our xml parser.
	    xml_parser_free($this->_xml_parser);
	    $this->_xml_parser = null;

	    return(true);

	} /* parse() */


	function _stripNameSpace($string)
	{
		$pos = strpos($string, ":");
		if ($pos === FALSE)
		{
			return($string);
		}

		$string = substr($string, $pos + 1);
		return($string);

	} /*_stripNameSpace() */

	// This event is fired when the xml parser comes across and opening
	// element in the xml.
	function startElement($parser, $tagName, $attrs) 
	{
		// if we are already inside an item then	
		if ($this->_insideitem) 
		{
			// take a copy of the tag name
			$this->_tag = $this->_stripNameSpace($tagName);
			
			// Set insidechannel to false - this is done to get
			// around the problem of some rss feeds wrapping their
			// news items inside a channel while others just
			// declare the channel on it's own at the top of the
			// rss feed.
			$this->_insidechannel = false;

			// Handle the attributes of specific tags.
			if ($tagName == 'ENCLOSURE')
			{
				$this->_enclosure['URL'] = trim($attrs['URL']);
				$this->_enclosure['LENGTH'] = trim($attrs['LENGTH']);
				$this->_enclosure['TYPE'] = trim($attrs['TYPE']);
				$this->_enclosurePresent = true;
			}
			elseif ($tagName == 'GUID')
			{
				if ($attrs['ISPERMALINK'] == "true")
				{
					$this->_isPermaLink = true;
				}
				else
				{
					$this->_isPermaLink = false;
				}
			}
			elseif ($tagName == 'LINK' && !empty($attrs['HREF']) 
				&& !empty($attrs['TYPE']))
			{
				// We only want entries of type="text/html"
				$temp = strtolower($attrs['TYPE']);

				if (!(strpos($temp, "text") === FALSE) ||
				    !(strpos($temp, "html") === FALSE))
				{
					$this->_item['link'] = trim($attrs['HREF']);
				}
			}
		} 
		
		// if we are on an ITEM tag
		elseif ($tagName == 'ITEM' || $tagName == 'ENTRY') 
		{
			// set insideitem to true
			$this->_insideitem = true;
		}
		
		// if we are on a CHANNEL tag
		elseif ($tagName == 'CHANNEL')
		{
			// set insidechannel to true
			$this->_insidechannel = true;
		}

		// if we are on a FEED tag
		elseif ($tagName == 'FEED')
		{
			// set insidechannel to true.
			$this->_insidechannel = true;
		}

		// if we are on an IMAGE tag
		elseif ($tagName == 'IMAGE') 
		{
			$this->_insideimage = true;
			$this->_insidechannel = false;
			$this->_insideitem = false;
		}
		
		// if we are inside an image
		elseif ($this->_insideimage)
		{
			$this->_tag = $this->_stripNameSpace($tagName);
			$this->_insidechannel = false;
		}

		// If we are inside a channel - do this bit last just in case
		// the channel tag wraps the whole news feed, then we'd just
		// be inside a channel all the time.
		elseif ($this->_insidechannel)
		{
			$this->_tag = $this->_stripNameSpace($tagName);

			if ($tagName == 'LINK' && !empty($attrs['HREF'])
				&& !empty($attrs['TYPE']))
			{
				// We only want entries of type="text/html"
				$temp = strtolower($attrs['TYPE']);

				if (!(strpos($temp, "text") === FALSE) ||
				    !(strpos($temp, "html") === FALSE))
				{
					$this->_channel_link = trim($attrs['HREF']);
				}
			}
		}

		// If we are on an RSS tag.
		elseif ($tagName == 'RSS')
		{
			// Dump some feed information.
			if ($this->_debug)
			{
				print("rssParser.startElement: opening rss feed ...<br /><pre>\n");
				print_r($attrs);
				print("</pre><br />\n");
			}
		}
	} /* startElement */


	// This event is fired when the xml parser comes across a closing
	// element in the xml.
	function endElement($parser, $tagName) 
	{
		// If it's an item then we want to add the item details to our
		// item details arrays.
		if ($tagName == 'ITEM' || $tagName == 'ENTRY') 
		{
			$this->_item['title'] = trim($this->_item['title']);
                        if ($this->_debug)
                        {
		          print('rssParser.endElement: done parsing item topic: "' . $this->_item['title'] . '"<br />' . "\n");
                        }

            		$this->_item['description'] = trim($this->_item['description']);
			$this->_item['link'] = trim($this->_item['link']);

			// Add additional items support.
			$this->_item['category'] = trim($this->_item['category']);
			$this->_item['pubDate'] = trim($this->_item['pubDate']);
			$this->_item['guid'] = trim($this->_item['guid']);
			$this->_item['duration'] = trim($this->_item['duration']);
			$this->_item['author'] = trim($this->_item['author']);
			$this->_item['email'] = trim($this->_item['email']);
			$this->_item['content'] = trim($this->_item['content']);
			$this->_item['isPermaLink'] = $this->isPermaLink;
			$this->_item['enclosure'] = trim($this->_item['enclosure']);
			$this->_item['commentRSS'] = trim($this->_item['commentRSS']);

			// This is a bit more complex element.
			if ($this->_enclosurePresent == true)
			{
				$this->_item['enclosureURL'] = $this->_enclosure['URL'];
				$this->_item['enclosureLength'] = $this->_enclosure['LENGTH'];
				$this->_item['enclosureType'] = $this->_enclosure['TYPE'];
			}

			// Make this data public.
           		array_push($this->items, $this->_item);

			// reset our item detail variables
            		$this->_item = array();
			$this->_insideitem = false;
			$this->_enclosurePresent = false;
			$this->_enclosure = array();
			$this->isPermaLink = false;
		}
		
		// if it's an image
		elseif ($tagName == 'IMAGE')
        	{
			$this->image_url = trim($this->_image_url);
			$this->image_link = trim($this->_image_link);
			$this->image_title = trim($this->_image_title);
			$this->image_height = intval(trim($this->_image_height));
			$this->image_width = intval(trim($this->_image_width));

			// reset our image detail variables
			$this->_image_url = '';
			$this->_image_link = '';
			$this->_image_title = '';
			$this->_image_height = '0';
			$this->_image_width = '0';
       		}

		// if it's a channel then we want to add the channel details to our channel details fields
		elseif ($tagName == 'CHANNEL' || $tagName == 'FEED')
		{
			$this->channel = trim($this->_channel);
			$this->channel_description = trim($this->_channel_description);
			$this->channel_link = trim($this->_channel_link);
			$this->channel_summary = trim($this->_channel_summary);

			// reset our channel detail variables
			$this->_channel = '';
			$this->_channel_description = '';
			$this->_channel_link = '';
			$this->_channel_summary = '';
			$this->_insidechannel = false;
		}
		elseif ($tagName == 'RSS')
		{
			// Dump some feed information.
			if ($this->_debug)
			{
				print("rssParser.endElement: closing rss feed ...<br />\n");
			}
		}
	}

	// this event is fired for each character of data which is read from the xml
	// use it to read the bits of information we are interested in
	function characterData($parser, $data) 
	{
		// if we are inside an item
		if ($this->_insideitem) 
		{
			// depending on what tag we are looking at
			// set the appropriate bit variable - notice that the data
			// is added on to the end of the variable, this is because 
			// it's read one bit at a time.
			switch ($this->_tag) 
			{
				case 'TITLE':
					$this->_item['title'] .= $data;
					break;
				case 'DESCRIPTION':
				case 'SUMMARY':
					$this->_item['description'] .= $data;
					break;
				case 'LINK':
					$this->_item['link'] .= $data;
					break;
				case 'CATEGORY':
					$this->_item['category'] .= $data;
					break;
				case 'SUBJECT':
					$this->_item['category'] .= $data;
					break;
				case 'PUBDATE':
				case 'CREATED':
					$this->_item['pubDate'] .= $data;
					break;
				case 'GUID':
					$this->_item['guid'] .= $data;
					break;
				case 'ENCLOSURE':
					$this->_item['enclosure'] .= $data;
					break;
				case 'DURATION':
					$this->_item['duration'] .= $data;
					break;
				case 'AUTHOR':
				case 'CREATOR':
				case 'NAME':
					$this->_item['author'] .= $data;
					break;
				case 'EMAIL':
					$this->_item['email'] .= $data;
					break;
				case 'CONTENT':
				case 'ENCODED':
					$this->_item['content'] .= $data;
					break;
				case 'COMMENTRSS':
					$this->_item['commentRSS'] .= $data;
					break;
			}
		}
		
        	// if was inside an image
        	elseif ($this->_insideimage)
        	{
			// depending on what tag we are looking at
			// set the appropriate bit variable - notice that the data
			// is added on to the end of the variable, this is because 
			// it's read one bit at a time.
			switch ($this->_tag) 
			{
				case 'URL':
					$this->_image_url .= $data;
					break;
				case 'LINK':
					$this->_image_link .= $data;
					break;
				case 'WIDTH':
					$this->_image_width .= $data;
					break;
				case 'HEIGHT':
					$this->_image_height .= $data;
					break;
				case 'TITLE':
					$this->_image_title .= $data;
					break;
			}
        	}

		// if we are inside a channel
		elseif ($this->_insidechannel)
		{
			// depending on what tag we are looking at
			// set the appropriate bit variable - notice that the data
			// is added on to the end of the variable, this is because 
			// it's read one bit at a time.
			switch ($this->_tag) 
			{
				case 'TITLE':
					$this->_channel .= $data;
					break;
				case 'DESCRIPTION':
				case 'TAGLINE':
					$this->_channel_description .= $data;
					break;
				case 'LINK':
					$this->_channel_link .= $data;
					break;
				case 'SUMMARY':
				case 'INFO':
					$this->_channel_summary .= $data;
					break;
			}
		}
	}
}

?>
